# Writings

Print out strings word for word or letter by letter.

## Installation

```
pip install writings
```

## Usage

-import writings

-to print **word for word** use write(text, delay)
-to print **letter by letter** use write_letters(text, delay)


---

## License

_steal this if you like, i do not care_
